# tspGraph.py

from grafikfenster import *
from tsp_greedy import *

### ---------------------------------------------------
class TSPGraph():
    """Klasse zum Zeichnen des Graphen"""
    
    def __init__(self, alle=False):
        """einfacher Konstruktor"""
        self.daten=[]
        self.alle=alle

    def wechsleAlle(self):
        self.Verberge()
        self.alle=not self.alle

    def GibFigur(self):
        if self.alle: return self.GibFigurAlle()
        else: return self.GibFigurTour()
        
    def GibFigurTour(self):
        """definiert und transformiert die zu zeichnende Figur
        Version fuer TSP"""
        gc = Zeichenflaeche.GibZeichenflaeche().GibGC()
        path = gc.CreatePath()
        path.MoveToPoint(self.daten[len(self.daten)-1])
        for ort in self.daten:
            path.AddLineToPoint(ort[0], ort[1])
        return path

    def GibFigurAlle(self):
        """definiert und transformiert die zu zeichnende Figur
        Version fuer Verbindung aller Knoten"""
        gc = Zeichenflaeche.GibZeichenflaeche().GibGC()
        path = gc.CreatePath()
        anzahlKnoten=len(self.daten)
        for i in range(anzahlKnoten):
            for j in range(anzahlKnoten):
                path.MoveToPoint(self.daten[i])
                if i!=j:
                    path.AddLineToPoint(self.daten[j])
        return path

    def setzeDaten(self, daten):
        """Veraendernde Methode fuer die Daten"""
        self.Verberge()
        self.daten = daten
        self.Zeige()

    def zeigeDaten(self):
        knotenDaten=[]
        for knoten in self.daten:
            knotenDaten.append(knoten)
        print(knotenDaten)

    def GibFarbe(self):
        return "black"

    def Verberge(self):
        """Veraendernde Methode fuer die Sichtbarkeit mit Wert False"""
        Zeichenflaeche.GibZeichenflaeche().Entferne(self)

    def Zeige(self):
        """Veraendernde Methode fuer die Sichtbarkeit mit Wert True"""
        Zeichenflaeche.GibZeichenflaeche().Zeichne(self)

### ---------------------------------------------------
class tspGraphApp(wx.App):
    
    def OnInit(self):
        self.fenster = GrafikFenster(None, "Grafik")
        self.SetTopWindow(self.fenster)
        self.fenster.Show(True)
        self.fenster.panel.Refresh()
        self.fenster.ZeigeShellFrame()
        #self.fenster.ZeigeFillingFrame()
        self.tspGraph=TSPGraph()
        self.tsp=TSP(self.tspGraph,20)
        self.daten=[]
        self.Alle()
        print('Mit app.Tour() die Tour und app.Alle() alle anzeigen')
        return True

    def Alle(self):
        """Zeigt die Verbindung aller Knoten"""
        self.tspGraph.wechsleAlle()
        self.tsp.verbindeAlle()
        
    def Tour(self):
        """Zeigt die Tour"""
        self.tspGraph.wechsleAlle()
        self.tsp.greedySuche()   
        
### ---------------------------------------------------
if __name__ == '__main__':
    app = tspGraphApp(redirect=False)
    # Parameterwert True, wenn Ausgaben in der Standard E/A angezeigt werden sollen
    app.MainLoop()
